==> pointpos_api-0.0.16.tar.gz: test/supplier_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for SupplierApi
void main() {
  var instance = new SupplierApi();

  group('tests for SupplierApi', () {
    // Create Supplier
    //
    // Create Supplier
    //
    //Future<Supplier> createSupplier(String authorization, String xAPIKey, Supplier body, { String xPin }) async 
    test('test createSupplier', () async {
      // TODO
    });

    // Delete Supplier By ID
    //
    // Delete Supplier By ID
    //
    //Future deleteSupplierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteSupplierByID', () async {
      // TODO
    });

    // Get Supplier List
    //
    // Get Supplier  List
    //
    //Future<List<Supplier>> findSupplier(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findSupplier', () async {
      // TODO
    });

    // Get Supplier By ID
    //
    // Get Supplier By ID
    //
    //Future<Supplier> getSupplierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getSupplierByID', () async {
      // TODO
    });

    // Update Supplier By ID
    //
    // Update [object Object] By ID
    //
    //Future<Supplier> updateSupplierByID(String authorization, String xAPIKey, String id, Supplier body, { String xPin }) async 
    test('test updateSupplierByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/supplier_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for SupplierApi
void main() {
  var instance = new SupplierApi();

  group('tests for SupplierApi', () {
    // Create Supplier
    //
    // Create Supplier
    //
    //Future<Supplier> createSupplier(String authorization, String xAPIKey, Supplier body, { String xPin }) async 
    test('test createSupplier', () async {
      // TODO
    });

    // Delete Supplier By ID
    //
    // Delete Supplier By ID
    //
    //Future deleteSupplierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteSupplierByID', () async {
      // TODO
    });

    // Get Supplier List
    //
    // Get Supplier  List
    //
    //Future<List<Supplier>> findSupplier(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findSupplier', () async {
      // TODO
    });

    // Get Supplier By ID
    //
    // Get Supplier By ID
    //
    //Future<Supplier> getSupplierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getSupplierByID', () async {
      // TODO
    });

    // Update Supplier By ID
    //
    // Update [object Object] By ID
    //
    //Future<Supplier> updateSupplierByID(String authorization, String xAPIKey, String id, Supplier body, { String xPin }) async 
    test('test updateSupplierByID', () async {
      // TODO
    });

  });
}
